@@ -28,6 +28,9 @@
 #'   lower=c(0, 0, 0.55); upper=c(0.24, 0.24, 1) } If no background filtering is
 #'   needed, set bounds to some non-numeric value (\code{NULL}, \code{FALSE},
 #'   \code{"off"}, etc); any non-numeric value is interpreted as \code{NULL}.
+#' @param alpha.channel Logical. If available, should alpha channel transparency be
+#'   used to mask background? See \code{\link{removeBackground}} for more
+#'   details.
 #' @param as.vec Logical. Should the bin sizes just be returned as a vector?
 #'   Much faster if only using \code{\link{chisqDistance}} for comparison metric.
 #' @param norm.pix Logical. Should RGB or HSV cluster values be normalized using
@@ -73,6 +76,7 @@
 getImageHist <- function(image, bins = 3, bin.avg = TRUE,
                          defaultClusters = NULL, lower = c(0, 0.55, 0),
                          upper = c(0.24, 1, 0.24), as.vec = FALSE,
+                         alpha.channel = TRUE,
                          norm.pix = FALSE, plotting = TRUE, hsv = FALSE,
                          title = "path", bounds = c(0, 1), ...) {
   
@@ -83,7 +87,8 @@ getImageHist <- function(image, bins = 3, bin.avg = TRUE,
   # If filepath was provided, check to make sure it exists or throw an error
   if (is.character(image)) {
     if (file.exists(image)) {
-      image <- loadImage(image, lower = lower, upper = upper, hsv = hsv)
+      image <- loadImage(image, lower = lower, upper = upper, hsv = hsv,
+                         alpha.channel = alpha.channel)
     }
   } else if (!is.list(image)) {
     stop("'image' must be either a path to the image", 
@@ -310,6 +315,9 @@ getHistColors <- function(bins, hsv = FALSE) {
 #'   lower=c(0, 0, 0.55); upper=c(0.24, 0.24, 1) } If no background filtering is
 #'   needed, set bounds to some non-numeric value (\code{NULL}, \code{FALSE},
 #'   \code{"off"}, etc); any non-numeric value is interpreted as \code{NULL}.
+#' @param alpha.channel Logical. If available, should alpha channel transparency be
+#'   used to mask background? See \code{\link{removeBackground}} for more
+#'   details.
 #' @param norm.pix Logical. Should RGB or HSV cluster values be normalized using
 #'   \code{\link{normalizeRGB}}?
 #' @param plotting Logical. Should the histogram generated for each image be
@@ -357,7 +365,8 @@ getHistColors <- function(bins, hsv = FALSE) {
 #'
 #' @export
 getHistList <- function(images, bins = 3, bin.avg = TRUE, 
-                        lower = c(0, 0.55, 0), upper = c(0.24, 1, 0.24), 
+                        lower = c(0, 0.55, 0), upper = c(0.24, 1, 0.24),
+                        alpha.channel = TRUE,
                         norm.pix = FALSE, plotting = FALSE, pausing = TRUE, 
                         hsv = FALSE, title = "path", img.type = FALSE, 
                         bounds = c(0, 1)) {
